__doc__="""CSV backup plugin for EconoAccount Product.
Creates tab delimited files of the data.

04/06-02
By Peter Bengtsson <econoaccount@peterbe.com>"""
__version__='0.0.3a'

from DateTime import DateTime
from Globals import DTMLFile
from DocumentTemplate import sequence

from Products.EconoAccount.Econo import EconoAccount


method = {'id':'CSV_backup',
          'title':'Back up data to CSV files',
          'description':'Create strings and return as files',
          'author':'Peter Bengtsson'}
if not method in EconoAccount.backup_methods:
    EconoAccount.backup_methods = EconoAccount.backup_methods + (method,)


CSV_backup = DTMLFile('csv_backup', globals())

def correctDelimiter(named):
    named = named.strip().lower()
    if named=='tab':
        return '\t'
    elif named=='comma':
        return ','
    else:
        return named

def downloadCSV(self, RESPONSE, dataname=None, filename=None,
                delimiter='tab'):
    """ determine what to download and wrap it up """
    if dataname is None:
        raise "NoDataname", "What kind of data must be specified"

    # get delimiter
    delimiter = correctDelimiter(delimiter)
    
    if not filename:
        filename = "%s-%s-%s"% (dataname.lower().capitalize(),
                                self.getRoot().getId(),
                                DateTime().strftime('%Y%m%d'))

    if RESPONSE is not None:
        RESPONSE.setHeader('Content-type','application/data')
        RESPONSE.setHeader('Content-Disposition','inline;filename=%s.csv' %\
                           filename)

    dataname = dataname.lower()
    
    if dataname == 'spendcodes':
        return self.GetSpendcodesString(delimiter)
    elif dataname == 'expenditures':
        return self.GetExpendituresString(delimiter)
    elif dataname == 'users':
        return self.GetUsersString(delimiter)
    

def GetSpendcodesString(self,d='\t'):
    """ create a long string of the spendcodes """

    t = "id%stitle%sdescription\n"%(d,d)
    all_spendcodes = self._getSpendcodes()
    for spendcode in all_spendcodes:
        t += spendcode.id + d + spendcode.title + d + \
             spendcode.getDescription() + "\n"
    return t

def GetExpendituresString(self, d='\t'):
    """ create a long string of the expenditures """

    t = "Id%sAmount%sDate%sSpendcode%sUserid\n"%(d,d,d,d)
    all_expenditures = self._getExpenditures()
    all_expenditures = sequence.sort(all_expenditures, (('datum',),))
    for exp in all_expenditures:
        try:
            userid =exp.userid
        except:
            userid =''
            
        t += exp.id +d+ str(exp.amount) +d+ exp.datum.strftime('%Y-%m-%d') +d+ \
             exp.spendcode +d+ userid + "\n"

    return t

def GetUsersString(self, d='\t'):
    """ create a long string of the users """

    t = "Id%sFirstname%sLastname%sEmail%sACL_username\n"%(d,d,d,d)
    all_users = self._getUsers()
    all_users = sequence.sort(all_users, (('firstname',),('lastname',)))
    for u in all_users:
        t += u.id +d+ u.firstname +d+ u.lastname +d+ \
             u.email +d+ u.acl_username + "\n"

    return t
        
    
# plug the above functions in as methods of the EconoAccount class
EconoAccount.CSV_backup = CSV_backup
EconoAccount.downloadCSV = downloadCSV
EconoAccount.GetSpendcodesString = GetSpendcodesString
EconoAccount.GetExpendituresString = GetExpendituresString
EconoAccount.GetUsersString = GetUsersString
